@@ -216,7 +216,8 @@ def supervenn(sets, set_annotations=None, figsize=DEFAULT_FIGSIZE, side_plots=Tr
               chunks_ordering='minimize gaps', sets_ordering=None,
               reverse_chunks_order=True, reverse_sets_order=True,
               max_bruteforce_size=DEFAULT_MAX_BRUTEFORCE_SIZE, seeds=DEFAULT_SEEDS, noise_prob=DEFAULT_NOISE_PROB,
-              side_plot_width=1.5, min_width_for_annotation=1, widths_minmax_ratio=0, side_plot_color='gray', **kw):
+              side_plot_width=1.5, min_width_for_annotation=1, widths_minmax_ratio=0, side_plot_color='gray', dpi=None,
+              **kw):
     """
     Plot a diagram visualizing relationship of multiple sets.
     :param sets: list of sets
@@ -244,6 +245,7 @@ def supervenn(sets, set_annotations=None, figsize=DEFAULT_FIGSIZE, side_plots=Tr
     :param noise_prob: probability of given element being equal to 1 in the noise array for randomized greedy algorithm
     :param side_plot_width: width of side plots in inches (default 1.5)
     :param side_plot_color: color of bars in side plots, default 'gray'
+    :param dpi: figure DPI
     :param min_width_for_annotation: for horizontal plot, don't annotate bars of widths less than this value (to avoid
     clutter)
     :param widths_minmax_ratio: desired max/min ratio of displayed chunk widths, default None (show actual widths)
@@ -264,16 +266,16 @@ def supervenn(sets, set_annotations=None, figsize=DEFAULT_FIGSIZE, side_plots=Tr
         height_ratios = [side_plot_width, fig_height - side_plot_width]
         width_ratios = [fig_width - side_plot_width, side_plot_width]
 
-        _, axes = plt.subplots(2, 2, figsize=figsize, gridspec_kw={'height_ratios': height_ratios,
-                                                                   'width_ratios': width_ratios,
-                                                                   'hspace': 0.0,
-                                                                   'wspace': 0.0})
+        _, axes = plt.subplots(2, 2, figsize=figsize, dpi=dpi, gridspec_kw={'height_ratios': height_ratios,
+                                                                            'width_ratios': width_ratios,
+                                                                            'hspace': 0.0,
+                                                                            'wspace': 0.0})
         for side_ax in axes[0, 1], axes[1, 1], axes[0, 0]:
             side_ax.set_xticks([])
             side_ax.set_yticks([])
         main_ax = axes[1, 0]
     else:
-        plt.figure(figsize=figsize)
+        plt.figure(figsize=figsize, dpi=dpi)
         main_ax = plt.gca()
 
     if set_annotations is None:
